/*{ STM32_Template::main.c ***********************************************
 
 * (c) 20100719 by Gregor Rebel
 
 * Features: 
   + Basic framework template of blinking LED for
     - Olimex STM32-P103 eval board
     - StdPeripheralsLibrary CMSIS V3.3.0 (tested)
     - GNU toolchain from CodeSourcery G++
     - local/ remote debugging (JTAG-Adapter may be connected to different computer)
   
 * Compile:
   ./compile.sh
   or
   make all

 * Flash onto u-controller:
   - change _openocd_flash.sh according to your board and adapter
   - flash binary
     ./_openocd_flash.sh main.bin
   
 * Debug:
   - change _openocd_gdb.sh and gdb.sh according to your board and adapter
   - start openocd as gdb-server (may even run on another computer connected over network)
     ./_openocd_gdb.sh
   - start gdb text user-interface in another shell
     ./gdb.sh
     
 * Note: This source makes use of text folding to improve hierarchical readability 
         It has been written with jEdit + plugin Configurable Fold Handler.
         Activate folding in your favourite text-editor for { and } 
         (fold-start and -end) for best visual experience.
         

 * Configuration of source-code:
    + stm32f10x_conf.h
      - modify according to your hardware (if differing from above) 
    
    + stm32f10x_it.c .
      - implement your own interrupthandlers in existing functions
      
    + main.c (this file)
      - extend as you like
      
    + makefile
      - all .c, .h and .s files in local directory are compiled and linked together automatically.
      
      
 * Prerequisites:
   + CodeSourcery G++
     - download from http://www.codesourcery.com/sgpp/lite/arm/portal/package6493/public/arm-none-eabi/arm-2010q1-188-arm-none-eabi-i686-pc-linux-gnu.tar.bz2
     - unpack somewhere
     - add to PATH (replace <XXX>according to your local filesystem):
       export PATH="<XXX>/SourceryG++/arm-2010q1/bin/:<XXX>/SourceryG++/arm-2010q1/libexec/gcc/arm-none-eabi/4.4.1/:$PATH"
 
   + StdPeripheralsLibrary CMSIS V3.3.0
     - download from http://www.st.com/stonline/products/support/micro/files/ stm32f10x_stdperiph_lib.zip
     - create link named StdPeripheralsLibrary to subfolder Libraries/ of unpacked archive 

    cp StdPeripheralsLibrary/CMSIS/CM3/DeviceSupport/ST/STM32F10x/stm32f10x.h Libraries/CMSIS/CM3/DeviceSupport/ST/STM32F10x/stm32f10x_orig.h
    chmod +w Libraries/CMSIS/CM3/DeviceSupport/ST/STM32F10x/stm32f10x.h
       - move assert-macro from stm32f10x_conf.h into stm32f10x.h
       - source: http://www.mikrocontroller.net/topic/156063#1472643

    cp StdPeripheralsLibrary/CMSIS/CM3/DeviceSupport/ST/STM32F10x/startup/gcc_ride7/startup_stm32f10x_md.s Libraries/CMSIS/CM3/DeviceSupport/ST/STM32F10x/startup/gcc_ride7/startup_stm32f10x_md_orig.s
    chmod +w Libraries/CMSIS/CM3/DeviceSupport/ST/STM32F10x/startup/gcc_ride7/startup_stm32f10x_md.s
      - change line (ResetHandler Bug: http://www.mikrocontroller.net/topic/156063#1476546):
        .word	Reset_Handler
     -> .word	Reset_Handler + 1
   
}*/
//{ Includes *************************************************************

#include "stm32f10x_conf.h"

// configure stm32f10x.h before including it
#define STM32F10X_MD
#define USE_STDPERIPH_DRIVER
#include "stm32f10x.h"

#include "stm32f10x_it.h"
#include "system_stm32f10x.h"
#include "bits.h"

//} Includes
//{ Defines **************************************************************

#define STACK_TOP 0x20000800
#define NVIC_CCR ((volatile unsigned long *)(0xE000ED14))

//} Defines
//{ Global Variables *****************************************************

GPIO_InitTypeDef GPIO_InitStructure;

//} Global Variables
//{ Function prototypes **************************************************

int main(void);
void myDelay(volatile unsigned long delay );
void Clk_Init (void);

//} Function prototypes
//{ Function definitions *************************************************

int main(void) {
    
        *NVIC_CCR = *NVIC_CCR | 0x200; /* Set STKALIGN in NVIC */
        Clk_Init();  // Init clock system
        //? SystemInit();

        RCC_APB2PeriphClockCmd(RCC_APB2Periph_AFIO, ENABLE);
        RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC | RCC_APB2Periph_GPIOA, ENABLE);
                    
        
        // Configure PC.12 as output push-pull (LED)
        GPIO_WriteBit(GPIOC,GPIO_Pin_12,Bit_SET);
        GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_12;
        GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
        GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
        GPIO_Init(GPIOC, &GPIO_InitStructure);
        
        
        while(1)
        {
            GPIOC->BRR |= 0x00001000;
            myDelay(500);
            GPIOC->BSRR |= 0x00001000;
            myDelay(500000);
         }
}
void myDelay(volatile unsigned long delay ) { 
/*{ myDelay()
 * Parameters: Int32U delay-period
 * Return: 
 *
 * Description: wait some amount of time
 *
}*/

 while(delay) delay--;
}
void Clk_Init (void) {
/*{ Clk_Init()
 * Parameters: Int32U Frequency
 * Return: Int32U
 *
 * Description: Init clock system
 *
 }*/
  
  // 1. Clocking the controller from internal HSI RC (8 MHz)
  RCC_HSICmd(ENABLE);
  // wait until the HSI is ready
  while(RCC_GetFlagStatus(RCC_FLAG_HSIRDY) == RESET);
  RCC_SYSCLKConfig(RCC_SYSCLKSource_HSI);
  // 2. Enable ext. high frequency OSC
  RCC_HSEConfig(RCC_HSE_ON);
  // wait until the HSE is ready
  while(RCC_GetFlagStatus(RCC_FLAG_HSERDY) == RESET);
  // 3. Init PLL
  RCC_PLLConfig(RCC_PLLSource_HSE_Div1,RCC_PLLMul_9); // 72MHz
//  RCC_PLLConfig(RCC_PLLSource_HSE_Div2,RCC_PLLMul_9); // 72MHz
  RCC_PLLCmd(ENABLE);
  // wait until the PLL is ready
  while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);
  // 4. Set system clock divders
  RCC_USBCLKConfig(RCC_USBCLKSource_PLLCLK_1Div5);
  RCC_ADCCLKConfig(RCC_PCLK2_Div8);
  RCC_PCLK2Config(RCC_HCLK_Div1);
  RCC_PCLK1Config(RCC_HCLK_Div2);
  RCC_HCLKConfig(RCC_SYSCLK_Div1);
  // Flash 1 wait state 
  *(vu32 *)0x40022000 = 0x12;
  // 5. Clock system from PLL
  RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);
}

//} Function definitions

