#!/bin/bash
#
#  Install script for STM Standard Peripherals Library
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition
# openSuSE 11.4


INSTALLPATH="FreeRTOS"

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi
echo "installing in $INSTALLPATH ..."

#sudo apt-get libgmp3-dev libmpfr-dev

#{ InstallFuncs v0.4 - written by Gregor Rebel

function cmd() {             # CMD,[STDOUT]               display + execute given command; records log + errors
  CMD="$1"
  StdOut="$2"
  
  if [ "$StdOut" != "" ]; then
    echo "`pwd`> $CMD >>$StdOut"
    $CMD >>$StdOut
  else
    echo "`pwd`> $CMD"
    $CMD $StdOut 2>CMD.err || CMD_ERROR="$CMD"
    CMDerr=`cat CMD.err`
    if [ "$CMDerr" != "" ]; then
      CMD_ERROR="$CMD"
    fi
  fi
}
function get() {             # URL_Prefix, File, OutFile  retrieves file from URL if not already done
  URL_Prefix="$1"
  gFile="$2"
  gOutFile="$3"
  
  if [ "$gOutFile" == "" ]; then
    gOutFile=$gFile
  fi

  if [ ! -e "$gFile" ]; then
    # CMD="wget $1$2"
    # echo "`pwd`> $CMD"
    # $CMD
#pwd
    cmd "wget $URL_Prefix$gFile -O $gOutFile" 
  fi
  if [ ! -e "$gFile" ]; then
    Get_Fails="$Get_Fails $gFile"
  fi
}
function dir() {             # Directory            creates directory if missing
  Directory="$1"
  
  if [ ! -d $Directory ]; then
    mkdir $Directory
  fi
}
function untgz() {           # Dir,Archiv           unpacks .tar.gz / .tgz archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then
    cmd "tar xzf $Archiv"
  fi
}
function untgj() {           # Dir,Archiv           unpacks .tar.bz2 / .tgj archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then
    cmd "tar xjf $Archiv"
  fi
}
function unZIP() {           # Dir,Archiv           unpacks .zip archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then

    cmd "unzip -o $Archiv" "unzip.log"
  fi
}
function addLine() {         # File,Line            adds given line to File if not already done
  File2Add2="$1"
  Line="$2"
  
  if [ ! -e $File2Add2 ]; then
    touch $File2Add2
  fi
  AlreadyPresent=`grep "$Line" $File2Add2`
  if [ "$AlreadyPresent" == "" ]; then
    cmd "echo $Line" "$File2Add2"
#  else
#    echo "file already up2date: $File2Add2"
  fi
}
function createLink() {      # Source,Link          creates symbolic link (removes old one before)
  Source="$1"
  Link="$2"
  User="$3"
  
  if [ "$User" != "" ]; then
    sudo -u$User rm -v $Link
  else
    rm -v $Link
  fi
  
  if [ "$User" != "" ]; then
    sudo -u$User ln -vs $Source $Link
  else
    ln -vs $Source $Link
  fi
}
function makeOrig() {        # File                 creates backup file XXX_orig if not present
  bFile="$1"
  
  BakFile="${bFile}_orig"
  if [ ! -e $BakFile ]; then
    cp $bFile $BakFile
  fi
}
function replaceInFile() {   # File,Search,Replace  replaces all occurences of "$Search" in file $File by "$Replace"
    File="$1"
    Search="$2"
    Replace="$3"
    
    echo "replace $File: $Search"
    echo "     -> $File: $Replace"
    #echo "sed -e \"s|$Search|$Replace|g\" $File"
    sed -e "s|$Search|$Replace|g" $File >${File}_2
    mv -f ${File}_2 ${File}
}
function findPrefix() {      #                      loads variable Prefix either with /usr or /usr/local according to system
  if [ -e "/usr/include/math.h" ]; then
    Prefix="/usr"
  else
    Prefix="/usr/local"
  fi
}
function installPackage() {  # Name1, Name2, ...    installs all named packages via local package manager (zypper or apt-get)
  if [ -x /usr/bin/zypper ]; then
    cmd "sudo zypper install -l -y $@"
  else
    cmd "sudo apt-get install $@"
  fi
}
function add2CleanUp() {     # File, Line           adds given line to cleanup file (if not already done)
    CleanUpFile="$1"
    Line="$2"
    
    if [ ! -e "$CleanUpFile" ]; then
      echo "#!/bin/bash"  >$CleanUpFile
      echo ""            >>$CleanUpFile
      chmod +x $CleanUpFile
    fi
    addLine "$CleanUpFile" "$Line"
}

#} InstallFuncs v0.4 - written by Gregor Rebel


dir $INSTALLPATH
cd $INSTALLPATH

Version="6.1.1"
Folder="FreeRTOSV${Version}"
if [ ! -d $Folder ]; then
  get http://downloads.sourceforge.net/project/freertos/FreeRTOS/V${Version}/ $Folder.zip
  unZIP $Folder $Folder.zip
  ln -s $Folder current
  add2CleanUp ../cleanup.sh "rm -Rf $INSTALLPATH/$Folder"
fi

File="current/Source/include/mpu_wrappers.h"
if [ ! -e "${File}_orig" ]; then #{
    mv ${File} ${File}_orig
    echo "modifing ${File}.."
    sed -e "s/\#define PRIVILEGED_FUNCTION __attribute__\(\(section\(\"privileged_functions\"\)\)\)/\#define PRIVILEGED_FUNCTION \/\/__attribute__\(\(section\(\"privileged_functions\"\)\)\)/g" ${File}_orig >${File}
fi #}

#X File="current/Demo/Common/drivers/ST/STM32F10xFWLib/inc/stm32f10x_type.h"
#X if [ ! -e "${File}_orig" ]; then #{
#X     makeOrig ${File}
#X     echo "`pwd`> modifing ${File}.."
#X     Comment="// previous content of this file is already defined in StdPeripheralsLibrary\/CMSIS\...\/stm32f10x.h"
#X     echo "$Comment" >${File}
#X 
#X     #X replaceInFile ${File} "typedef signed long  s32;" "// typedef signed long  s32; // $Comment"
#X     #X replaceInFile ${File} "typedef signed short s16;" "// typedef signed short s16; // $Comment"
#X     #X replaceInFile ${File} "typedef signed char  s8;"  "// typedef signed char  s8;  // $Comment"
#X   
#X     #X replaceInFile ${File} "typedef volatile signed long  vs32;" "// typedef volatile signed long  vs32; // $Comment"
#X     #X replaceInFile ${File} "typedef volatile signed short vs16;" "// typedef volatile signed short vs16; // $Comment"
#X     #X replaceInFile ${File} "typedef volatile signed char  vs8;"  "// typedef volatile signed char  vs8; // $Comment"
#X 
#X     #X replaceInFile ${File} "typedef unsigned long  u32;"         "// typedef unsigned long  u32; // $Comment"
#X     #X replaceInFile ${File} "typedef unsigned short u16;"         "// typedef unsigned short u16; // $Comment"
#X     #X replaceInFile ${File} "typedef unsigned char  u8;"          "// typedef unsigned char  u8; // $Comment"
#X fi #}

File="current/Source/include/task.h"
if [ ! -e "${File}_orig" ]; then #{
    makeOrig ${File}
    echo "`pwd`> modifing ${File}.. (correct type of usStackDepth improves visibility during gcc debugging)"

    replaceInFile ${File} "unsigned short usStackDepth" "size_t usStackDepth"
fi #}

File="current/Source/tasks.c"
if [ ! -e "${File}_orig" ]; then #{
    makeOrig ${File}
    echo "`pwd`> modifing ${File}.. (correct type of usStackDepth improves visibility during gcc debugging)"

    replaceInFile ${File} "unsigned short usStackDepth" "size_t usStackDepth"
fi #}

exit 0
