#!/bin/bash
#
#  Install script for ST Standard Peripherals Library
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition


INSTALLPATH="StdPeripheralsLibrary"

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi
echo "installing in $INSTALLPATH ..."

#sudo apt-get libgmp3-dev libmpfr-dev

#{ InstallFuncs v0.4 - written by Gregor Rebel

function cmd() {             # CMD,[STDOUT]               display + execute given command; records log + errors
  CMD="$1"
  StdOut="$2"
  
  if [ "$StdOut" != "" ]; then
    echo "`pwd`> $CMD >>$StdOut"
    $CMD >>$StdOut
  else
    echo "`pwd`> $CMD"
    $CMD $StdOut 2>CMD.err || CMD_ERROR="$CMD"
    CMDerr=`cat CMD.err`
    if [ "$CMDerr" != "" ]; then
      CMD_ERROR="$CMD"
    fi
  fi
}
function get() {             # URL_Prefix, File, OutFile  retrieves file from URL if not already done
  URL_Prefix="$1"
  gFile="$2"
  gOutFile="$3"
  
  if [ "$gOutFile" == "" ]; then
    gOutFile=$gFile
  fi

  if [ ! -e "$gFile" ]; then
    # CMD="wget $1$2"
    # echo "`pwd`> $CMD"
    # $CMD
#pwd
    cmd "wget $URL_Prefix$gFile -O $gOutFile" 
  fi
  if [ ! -e "$gFile" ]; then
    Get_Fails="$Get_Fails $gFile"
  fi
}
function dir() {             # Directory            creates directory if missing
  Directory="$1"
  
  if [ ! -d $Directory ]; then
    mkdir $Directory
  fi
}
function untgz() {           # Dir,Archiv           unpacks .tar.gz / .tgz archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then
    cmd "tar xzf $Archiv"
  fi
}
function untgj() {           # Dir,Archiv           unpacks .tar.bz2 / .tgj archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then
    cmd "tar xjf $Archiv"
  fi
}
function unZIP() {           # Dir,Archiv           unpacks .zip archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then

    cmd "unzip -o $Archiv" "unzip.log"
  fi
}
function addLine() {         # File,Line            adds given line to File if not already done
  File2Add2="$1"
  Line="$2"
  
  if [ ! -e $File2Add2 ]; then
    touch $File2Add2
  fi
  AlreadyPresent=`grep "$Line" $File2Add2`
  if [ "$AlreadyPresent" == "" ]; then
    cmd "echo $Line" "$File2Add2"
#  else
#    echo "file already up2date: $File2Add2"
  fi
}
function createLink() {      # Source,Link          creates symbolic link (removes old one before)
  Source="$1"
  Link="$2"
  User="$3"
  
  if [ "$User" != "" ]; then
    sudo -u$User rm -v $Link
  else
    rm -v $Link
  fi
  
  if [ "$User" != "" ]; then
    sudo -u$User ln -vs $Source $Link
  else
    ln -vs $Source $Link
  fi
}
function makeOrig() {        # File                 creates backup file XXX_orig if not present
  bFile="$1"
  
  BakFile="${bFile}_orig"
  if [ ! -e $BakFile ]; then
    cp $bFile $BakFile
  fi
}
function replaceInFile() {   # File,Search,Replace  replaces all occurences of "$Search" in file $File by "$Replace"
    File="$1"
    Search="$2"
    Replace="$3"
    
    echo "replace $File: $Search"
    echo "     -> $File: $Replace"
    #echo "sed -e \"s|$Search|$Replace|g\" $File"
    sed -e "s|$Search|$Replace|g" $File >${File}_2
    mv -f ${File}_2 ${File}
}
function findPrefix() {      #                      loads variable Prefix either with /usr or /usr/local according to system
  if [ -e "/usr/include/math.h" ]; then
    Prefix="/usr"
  else
    Prefix="/usr/local"
  fi
}
function installPackage() {  # Name1, Name2, ...    installs all named packages via local package manager (zypper or apt-get)
  if [ -x /usr/bin/zypper ]; then
    cmd "sudo zypper install -l -y $@"
  else
    cmd "sudo apt-get install $@"
  fi
}
function add2CleanUp() {     # File, Line           adds given line to cleanup file (if not already done)
    CleanUpFile="$1"
    Line="$2"
    
    if [ ! -e "$CleanUpFile" ]; then
      echo "#!/bin/bash"  >$CleanUpFile
      echo ""            >>$CleanUpFile
      chmod +x $CleanUpFile
    fi
    addLine "$CleanUpFile" "$Line"
}

#} InstallFuncs v0.4 - written by Gregor Rebel

dir $INSTALLPATH
cd $INSTALLPATH

Archive="stm32f10x_stdperiph_lib.zip"
# get http://www.st.com/stonline/products/support/micro/files/ $Archive
get http://www.st.com/internet/com/SOFTWARE_RESOURCES/SW_COMPONENT/FIRMWARE/ $Archive

# find name ofu only directory
# StdPeripheralsLibrary/STM32F10x_StdPeriph_Lib_V3.4.0/Libraries/CMSIS/CM3/DeviceSupport/ST/STM32F10x/stm32f10x.h

unZIP STM32F10x_StdPeriph_Lib $Archive || mv -f $Archive ${Archive}_bad
rm current 2>/dev/null
LibraryDir=`find ./  -maxdepth 1 -mindepth 1 -type d -print`
ln -sv $LibraryDir current
cd current

File="Libraries/CMSIS/CM3/DeviceSupport/ST/STM32F10x/stm32f10x.h"
if [ -e ${File}_orig ]; then
    mv -f ${File}_orig $File 
fi
mv -f $File ${File}_orig

echo "  creating macro assert_param in $File"
Note="  Note: Manually remove assert_param from your stm32f10x_conf.h !"
echo $Note
addLine ../Notes.txt $Note
addLine ../Notes.txt "StdPeripheralLibrary-> http://www.mikrocontroller.net/articles/STM32F10x_Standard_Peripherals_Library  (german)
folder ToolChain/documentation"

# system_stm32f10x.c is required to be found by the compiler so we put it aside its header file
cp -v Project/STM32F10x_StdPeriph_Template/system_stm32f10x.c Libraries/CMSIS/CM3/DeviceSupport/ST/STM32F10x/
addLine ../Notes.txt "system_stm32f10x.c moved beside its header file (-> https://my.st.com/public/STe2ecommunities/mcu/Lists/ARM%20CortexM3%20STM32/Flat.aspx?RootFolder=%2Fpublic%2FSTe2ecommunities%2Fmcu%2FLists%2FARM%20CortexM3%20STM32%2FMissing%20file%20in%20new%203.4.0%20libraries%20system_stm32f10x.c&FolderCTID=0x01200200770978C69A1141439FE559EB459D758000626BE2B829C32145B9EB5739142DC17E&currentviews=320)"

cat >script.sed <<"END_OF_TEXT"
/#include <stdint.h>/a\
#ifdef  USE_FULL_ASSERT\n
\n
// This assert_param macro has been copied here from stm32f10x_conf.h to\n
// circumvent gcc compiler errors.\n
\n
/**\n
  * @brief  The assert_param macro is used for function's parameters check.\n
  * @param  expr: If expr is false, it calls assert_failed function\n
  *   which reports the name of the source file and the source\n
  *   line number of the call that failed.\n 
  *   If expr is true, it returns no value.\n
  * @retval None\n
  */\n
  #define assert_param(expr) ((expr) ? (void)0 : assert_failed((uint8_t *)__FILE__, __LINE__))\n
  void assert_failed(uint8_t* file, uint32_t line);\n
#else\n
  #define assert_param(expr) ((void)0)\n
#endif /* USE_FULL_ASSERT */\n

END_OF_TEXT

    # concatenate all lines which contain \n (sed requires this)
    awk '/\\n/{printf "%s",$0;next}{print}' script.sed >script2.sed
    
    # insert lines after "#include <stdint.h>"
    sed -f script2.sed ${File}_orig >$File

exit 0

#{ DEPRECATED stuff below ---------------------------------

function patchU8() {
  Folder="$1"
  File="$2"
  
  if [ ! -e $Folder${File}_orig ]; then
    echo "patching $Folder${File} (variable names u8,u16,u32 are used as datatypes in FreeRTOS)"
    OldPWD=`pwd`
    cd $Folder
    mv -f ${File} ${File}_orig
    sed -e "s/u8/UByte/g"   ${File}_orig >${File}2
    sed -e "s/u16/UShort/g" ${File}_orig >${File}3
    sed -e "s/u32/ULong/g"  ${File}_orig >${File}
    cd $OldPWD
  fi	
}

#patchU8 "Libraries/CMSIS/CM3/DeviceSupport/ST/STM32F10x/" "stm32f10x.h"
#patchU8 "Libraries/CMSIS/CM3/CoreSupport/"                "core_cm3.h"
#patchU8 "Libraries/STM32F10x_StdPeriph_Driver/src/"       "stm32f10x_gpio.c"

#}DEPRECATED
