#!/bin/bash

#
#  Install script for Open On-Chip Debugger tool made by Dominic Rath.
#  Script written by Gregor Rebel 2010-2011.
#  libFTDI - FTDI USB driver with bitbang mode
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition
# openSuSE 11.4

#{ InstallFuncs v0.4 - written by Gregor Rebel

function cmd() {             # CMD,[STDOUT]               display + execute given command; records log + errors
  CMD="$1"
  StdOut="$2"
  
  if [ "$StdOut" != "" ]; then
    echo "`pwd`> $CMD >>$StdOut"
    $CMD >>$StdOut
  else
    echo "`pwd`> $CMD"
    $CMD $StdOut 2>CMD.err || CMD_ERROR="$CMD"
    CMDerr=`cat CMD.err`
    if [ "$CMDerr" != "" ]; then
      CMD_ERROR="$CMD"
    fi
  fi
}
function get() {             # URL_Prefix, File, OutFile  retrieves file from URL if not already done
  URL_Prefix="$1"
  gFile="$2"
  gOutFile="$3"
  
  if [ "$gOutFile" == "" ]; then
    gOutFile=$gFile
  fi

  if [ ! -e "$gFile" ]; then
    # CMD="wget $1$2"
    # echo "`pwd`> $CMD"
    # $CMD
#pwd
    cmd "wget $URL_Prefix$gFile -O $gOutFile" 
  fi
  if [ ! -e "$gFile" ]; then
    Get_Fails="$Get_Fails $gFile"
  fi
}
function dir() {             # Directory            creates directory if missing
  Directory="$1"
  
  if [ ! -d $Directory ]; then
    mkdir $Directory
  fi
}
function untgz() {           # Dir,Archiv           unpacks .tar.gz / .tgz archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then
    cmd "tar xzf $Archiv"
  fi
}
function untgj() {           # Dir,Archiv           unpacks .tar.bz2 / .tgj archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then
    cmd "tar xjf $Archiv"
  fi
}
function unZIP() {           # Dir,Archiv           unpacks .zip archive if Dir is missing
  Dir="$1"
  Archiv="$2"
  

  if [ ! -d $Dir ]; then

    cmd "unzip -o $Archiv" "unzip.log"
  fi
}
function addLine() {         # File,Line            adds given line to File if not already done
  File2Add2="$1"
  Line="$2"
  
  if [ ! -e $File2Add2 ]; then
    touch $File2Add2
  fi
  AlreadyPresent=`grep "$Line" $File2Add2`
  if [ "$AlreadyPresent" == "" ]; then
    cmd "echo $Line" "$File2Add2"
#  else
#    echo "file already up2date: $File2Add2"
  fi
}
function createLink() {      # Source,Link          creates symbolic link (removes old one before)
  Source="$1"
  Link="$2"
  User="$3"
  
  if [ "$User" != "" ]; then
    sudo -u$User rm -v $Link
  else
    rm -v $Link
  fi
  
  if [ "$User" != "" ]; then
    sudo -u$User ln -vs $Source $Link
  else
    ln -vs $Source $Link
  fi
}
function makeOrig() {        # File                 creates backup file XXX_orig if not present
  bFile="$1"
  
  BakFile="${bFile}_orig"
  if [ ! -e $BakFile ]; then
    cp $bFile $BakFile
  fi
}
function replaceInFile() {   # File,Search,Replace  replaces all occurences of "$Search" in file $File by "$Replace"
    File="$1"
    Search="$2"
    Replace="$3"
    
    echo "replace $File: $Search"
    echo "     -> $File: $Replace"
    #echo "sed -e \"s|$Search|$Replace|g\" $File"
    sed -e "s|$Search|$Replace|g" $File >${File}_2
    mv -f ${File}_2 ${File}
}
function findPrefix() {      #                      loads variable Prefix either with /usr or /usr/local according to system
  if [ -e "/usr/include/math.h" ]; then
    Prefix="/usr"
  else
    Prefix="/usr/local"
  fi
}
function installPackage() {  # Name1, Name2, ...    installs all named packages via local package manager (zypper or apt-get)
  if [ -x /usr/bin/zypper ]; then
    cmd "sudo zypper install -l -y $@"
  else
    cmd "sudo apt-get install $@"
  fi
}
function add2CleanUp() {     # File, Line           adds given line to cleanup file (if not already done)
    CleanUpFile="$1"
    Line="$2"
    
    if [ ! -e "$CleanUpFile" ]; then
      echo "#!/bin/bash"  >$CleanUpFile
      echo ""            >>$CleanUpFile
      chmod +x $CleanUpFile
    fi
    addLine "$CleanUpFile" "$Line"
}

#} InstallFuncs v0.4 - written by Gregor Rebel

installPackage texlive

INSTALLPATH="OpenOCD"
dir $INSTALLPATH
cd $INSTALLPATH

File="openocd-0.4.0"
get http://download.berlios.de/openocd/ ${File}.tar.bz2
get http://download.berlios.de/openocd/ openocd.pdf
untgj ${File} ${File}.tar.bz2
add2CleanUp ../cleanup.sh "rm -Rf $INSTALLPATH/$File"

if [ ! -d ${File} ]; then
  echo "ERROR: Cannot download file (folder ${File} not found in `pwd`)!"
  exit 5
fi
cd ${File}/
if [ ! -e Install_OK ]; then
  echo "compiling $File ----------------------------------------------"
  echo "clean..." && make clean >clean.log 2>&1
  #./configure  --prefix=$Prefix --enable-usbprog --enable-ioutil --enable-oocd_trace --enable-jlink --enable-ft2232_ftd2xx && make -j2 && sudo make install && touch Install_OK
  echo "configure >configure.log..." && ./configure --prefix=$Prefix --enable-ioutil --enable-oocd_trace --enable-jlink --enable-ft2232_libftdi >configure.log 2>&1 && \
  echo "make      >make.log..."      && make -j2 >make.log 2>&1 && \
  echo "pdf       >pdf.log..."       && make pdf -j2 >pdf.log 2>&1 ; \
  echo "install   >install.log..."   && sudo make install >install.log 2>&1 && \
  touch Install_OK

  if [ ! -e Install_OK ]; then
    echo "Error during compiling ${File}!"
    echo "Check log files:"
    find `pwd`/ -name "*.log" -exec echo "  less {}" \;
    find `pwd`/ -name "*.err" -exec echo "  less {}" \;
    exit 10
  else
    IsInstalled=`openocd --version  2>&1 | grep Debugger`
    if [ "$IsInstalled" != "" ]; then
      sudo chmod 4755 $Prefix/bin/openocd
      echo "${File} installed successfully: $IsInstalled"
    else
      echo "ERROR: OpenOCD did NOT install successfully!"
      exit 10
    fi
  fi
else
  echo "${File} already compiled (rm ` pwd`/Install_OK)."
  sudo make install >install.log 2>&1
  sudo chmod 4755 `which openocd`
fi
cd ..
cd ..

exit 0
